(*mathematica script to calculate detector thermal energy from noise vs
BW fit, calibration fit, FEA modal mass and (eventually) calibration
force calculation, Q and resonant frequency measurement.  This version
is for 20130723 noise v BW and 20130802 calibration, TA1205 modal
mass.
version 2: some quantities re-labeled
version 3: ?
version 4: uses HOM's value of the force, JCLs error
version 5: uses values from HOM draft of 20131202, my 7/23 BW data
version 6: uses values from HOM draft of 20131202, my 8/06 BW data,
with various points masked
version 7: uses values from HOM draft of 20121202, my 08/06 BW data,
highest off-res point masked*)

(*Clear variables*)
Clear[kB,e0,qe,
      UTin2,UDin,f0,T,Qexp,mm,ld,wd,V0,zgt,chixy,
      ETp,
      chiika,chiik,
      zg,w0,
      Ad,FDexp,FDM,FDMH,
      ET,
      eUTin2,eUDin,ef0,erT,eQexp,emm,eld,ewd,eV0,ezgt,
      eETp,
      ezg,ew0,
      eAd,eFDexp,eFDM,eFDMH,
      eET]

(*constants*)
kB = 1.381 10^-23 (*Boltzmann constant, J/K*)
e0 = 8.85 10^-12  (*permittivity constant, F/m*)
qe = 1.602 10^-19   (*electron charge, C*)

(*mean data*)
UTin2 = 7.9 10^-9  (*noise power from noise vs BW [draft] *)
UDin  = 6.195 10^-2 (*calibration signal at LI input [draft]*)
f0    = 1223.395    (*resonant frequency, Hz [logbook]*)
T     = 3.02 10^2   (*Temperature, K [logbook]*)
Qexp  = 2.08 10^4   (*Q [logbook]*)
mm    = 0.93 10^-3  (*modal mass, kg [draft]*)
wd    = 1.144 10^-2 (*detector small rectangle width, m*)
ld    = 5.08 10^-3  (*detector small rectangle length, m*)
V0    = 8.0 10^-1   (*resonant source calibration voltage, V [logbook]*)
zgt   = 1.20 10^2   (*gap, ticks [logbook]*)
chixy = 273         (*displacement of large rectangle corner
                      subtended by probe, arb [HOM 8/22/13 report]*)

(*Prediction*)
ETp = 0.5 kB T

(*mode data*)
chiika =
{0,85,173,266,367,473,580,689,798,908,
 0,91,183,280,382,487,593,703,811,921,
 0,96,193,292,394,500,607,715,824,933,
 0,99,199,301,405,511,619,727,837,946,
 0,102,205,309,415,521,630,738,848,958,
 0,105,210,316,423,531,640,749,859,969,
 0,107,214,322,431,539,650,759,869,980,
 0,109,219,327,437,548,658,769,879,990,
 0,111,222,333,444,555,667,778,889,1000}    (*complete half small
                                         rectangle mode displacements,
                                         arb [HOM, 8/22/13]*)
chiik  = Mean[chiika] (*mean detector small rectangle displacement due
                        to ES calibration force, arb*)

(*error data*)
eUTin2 = 3.0 10^-10 (*noise power from noise vs BW [draft] *)
eUDin  = 5.0 10^-5  (*calibration signal at LI input, [draft]*)
ef0    = 2.0 10^-3  (*resonant frequency, Hz [logbook]*)
erT     = 1.0 10^-1  (*Temperature, K [logbook]*)
eQexp  = 1.0 10^2   (*Q [logbook]*)
emm    = 0.05 10^-3 (*modal mass, kg [draft]*)
eld    = 1.0 10^-4  (*detector small rectangle width, m*)
ewd    = 1.0 10^-4  (*detector small rectangle length, m*)
eV0    = 1.0 10^-3  (*resonant source calibration voltage, V [logbook]*)
ezgt   = 5.0 10^0   (*gap, ticks [logbook]*)

(*conversions*)
zg   = 3.175 10^-6 zgt (*gap, m*)  
w0   = 2. Pi f0        (*detector resonant angular freq., 1/s*)

(*calculations*)
Ad = ld wd/2          (*detector area subtended, m^2*)

(*ES force*)
FDexp = e0 Ad V0^2/(4 zg^2)
FDM   = FDexp chiik/chixy
FDMH  = 4.9 10^-10 (*effective force at probe [draft]*)

(*Predicted signal*)
ET = UTin2 (Qexp^2) (FDMH^2)/(2. (UDin^2) mm (w0^2)) (*predicted T signal, J*)

(*err calculations*)
(*prediction*)
eETp = ETp (erT/T)

(*detector overlap*)
eAdl = Ad (eld/ld)
eAdw = Ad (ewd/wd)
eAd  = Sqrt[(eAdl^2)+(eAdw^2)]

(*err ES force*)
eFDA  = FDM (eAd/Ad)
eFDV0 = 2. FDM (eV0/V0)
eFDzg = 2. FDM (ezgt/zgt)
eFDM  = Sqrt[(eFDA^2)+(eFDV0^2)+(eFDzg^2)]
eFDMHv = FDMH (eFDM/FDM)
eFDMH = 0.4 10^-10 (*[draft]*)

(*err Predicted signal*)
eETUT = ET (eUTin2/UTin2)
eETUD = 2. ET (eUDin/UDin)
eETw0 = 2. ET (ef0/f0)
eETQ = 2. ET (eQexp/Qexp)
eETmm = ET (emm/mm)
eETFD = 2. ET (eFDMH/FDMH)
eET  = Sqrt[(eETUD^2)+(eETw0^2)+(eETUT^2)+(eETQ^2)+(eETmm^2)+(eETFD^2)]

(*Print*)
Print["subtended detector area, m^2              = ", Ad]
Print["mean small rectangle displacement, COMSOL = ", N[chiik]] 
Print["calibration signal at LI INPUT, V^2       = ", UDin^2]
Print["ES calibration force, N                   = ", FDexp]
Print["ES force err, N                           = ", (FDexp/FDM) eFDM]
Print["effective ES force at probe, N            = ", FDMH]
Print["effective ES at probe force err, N 0.4?   = ", eFDMHv]
Print["--------Results----------"]
Print["T-Energy = (", SetPrecision[ET,3]," +/- ",SetPrecision[eET,3],") J"]
Print["1/2 kT   = (", SetPrecision[ETp,3]," +/- ",SetPrecision[eETp,3],") J"]
Print["T-Energy = (", SetPrecision[ET/qe,3]," +/- ",SetPrecision[eET/qe,3],") eV"]
Print["1/2 kT   = (", SetPrecision[ETp/qe,3]," +/- ",SetPrecision[eETp/qe,3],") eV"]
Print["T, det   = (", SetPrecision[2. ET/kB,3]," +/- ",SetPrecision[2. eET/kB,3],") K"]
Print["T, sens  = (", SetPrecision[T,3]," +/- ",SetPrecision[erT,3],") K"]
Print["--------Error Budget----------"]
Print["frac err T-noise power = ",eETUT/ET]
Print["frac err Calib signal  = ",eETUD/ET]
Print["frac err resonant freq = ",eETw0/ET]
Print["frac err Q             = ",eETQ/ET]
Print["frac err modal mass    = ",eETmm/ET]
Print["frac err ES force calc = ",eETFD/ET]
Print["--------ES Force Error Budget----------"]
Print["frac err overlap = ",eFDA/FDM]
Print["frac err drive V = ",eFDV0/FDM]
Print["frac err gap     = ",eFDzg/FDM]
